#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 recursion-schemes
version:              5.2.3
visibility:           public
id:                   recursion-schemes-5.2.3-AJ9Vg3SzIwVBKjMGhdpVaa
key:                  recursion-schemes-5.2.3-AJ9Vg3SzIwVBKjMGhdpVaa
license:              BSD-2-Clause
copyright:            Copyright (C) 2008-2015 Edward A. Kmett
maintainer:
    "Samuel Gélineau" <gelisam@gmail.com>,
    "Ryan Scott" <ryan.gl.scott@gmail.com>,
    "Luc Tielen" <luc.tielen@gmail.com>

author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/recursion-schemes/
synopsis:
    Representing common recursion patterns as higher-order functions

description:
    Many recursive functions share the same structure, e.g. pattern-match on the input and, depending on the data constructor, either recur on a smaller input or terminate the recursion with the base case. Another one: start with a seed value, use it to produce the first element of an infinite list, and recur on a modified seed in order to produce the rest of the list. Such a structure is called a recursion scheme. Using higher-order functions to implement those recursion schemes makes your code clearer, faster, and safer. See README for details.

category:             Control, Recursion
abi:                  dfb56a421091086d140c3927488b8d80
exposed:              True
exposed-modules:
    Data.Functor.Base Data.Functor.Foldable Data.Functor.Foldable.TH

hidden-modules:       Paths_recursion_schemes
import-dirs:          /usr/lib/ghc-9.6.6/site-local/recursion-schemes-5.2.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/recursion-schemes-5.2.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/recursion-schemes-5.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recursion-schemes
hs-libraries:         HSrecursion-schemes-5.2.3-AJ9Vg3SzIwVBKjMGhdpVaa
depends:
    base-4.18.2.1 comonad-5.0.10-8e7WZ5YFm5q8lJvWEvWWiA
    containers-0.6.7 data-fix-0.3.4-7hd2HcUzeuSB4ZFiM2eK02
    free-5.2-5i1GhxtT1oXBBGtYqQWPt7 template-haskell-2.20.0.0
    th-abstraction-0.6.0.0-6nwiZFs5BlM71phLjoyZV3 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-recursion-schemes/html/recursion-schemes.haddock

haddock-html:         /usr/share/doc/haskell-recursion-schemes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

